Ltix.DeepLinking.ContentItem.LtiResourceLink (Ltix v0.1.0)

Copy Markdown View Source

An LTI resource link content item for Deep Linking responses.

All fields are optional. The platform can use the tool's base URL when no url is provided. Include a line_item to have the platform auto-create a gradebook column for the link.

See Building Content Items for common patterns including line items, custom parameters, and availability windows.

Options

  • :title (String.t/0) - Title for the content item.

  • :text (String.t/0) - Plain-text description.

  • :extensions (map/0) - Required. Vendor-specific extension properties. The default value is %{}.

  • :available (map/0)

  • :url (String.t/0) - Launch URL for the resource link.

  • :icon (map/0) - Icon or thumbnail for the LTI resource link.

  • :thumbnail (map/0) - Icon or thumbnail for the LTI resource link.

  • :line_item (map/0)

  • :window (map/0) - Window presentation for the LTI resource link.

  • :iframe (map/0)

  • :custom (map/0) - Custom parameter key-value pairs.

  • :submission (map/0)

Summary

Functions

Create a new LTI resource link content item.

Types

t()

@type t() :: %Ltix.DeepLinking.ContentItem.LtiResourceLink{
  available: %{
    optional(:start_date_time) => binary(),
    optional(:end_date_time) => binary()
  },
  custom: %{optional(binary()) => binary()},
  extensions: %{optional(binary()) => any()},
  icon: %{
    optional(:width) => integer(),
    :url => binary(),
    optional(:height) => integer()
  },
  iframe: %{optional(:width) => integer(), optional(:height) => integer()},
  line_item: %{
    optional(:label) => binary(),
    optional(:tag) => binary(),
    :score_maximum => number(),
    optional(:resource_id) => binary(),
    optional(:grades_released) => boolean()
  },
  submission: %{
    optional(:start_date_time) => binary(),
    optional(:end_date_time) => binary()
  },
  text: binary(),
  thumbnail: %{
    optional(:width) => integer(),
    :url => binary(),
    optional(:height) => integer()
  },
  title: binary(),
  url: binary(),
  window: %{
    optional(:width) => integer(),
    optional(:height) => integer(),
    optional(:target_name) => binary(),
    optional(:window_features) => binary()
  }
}

Functions

new(opts)

@spec new(keyword()) :: {:ok, t()} | {:error, Exception.t()}

Create a new LTI resource link content item.

Examples

iex> {:ok, link} = Ltix.DeepLinking.ContentItem.LtiResourceLink.new([])
iex> link.url
nil

iex> {:ok, link} = Ltix.DeepLinking.ContentItem.LtiResourceLink.new(url: "https://tool.example.com")
iex> link.url
"https://tool.example.com"