Signed JWT and return URL from a Deep Linking response.
Deliver the JWT to the platform by POSTing it to return_url as the
JWT form parameter via an auto-submitting HTML form.
See the Deep Linking guide for the full workflow.
Signed JWT and return URL from a Deep Linking response.
Deliver the JWT to the platform by POSTing it to return_url as the
JWT form parameter via an auto-submitting HTML form.
See the Deep Linking guide for the full workflow.