Ltix.LaunchClaims.LaunchPresentation (Ltix v0.1.0)

Copy Markdown View Source

How the platform expects the tool to be presented.

All fields are optional. document_target indicates the browser context for the launch — typically "frame", "iframe", or "window", but unknown values are accepted.

Examples

iex> Ltix.LaunchClaims.LaunchPresentation.from_json(%{"document_target" => "iframe"})
{:ok, %Ltix.LaunchClaims.LaunchPresentation{document_target: "iframe", height: nil, width: nil, return_url: nil, locale: nil}}

Summary

Functions

Parse a launch presentation claim from a JSON map.

Types

t()

@type t() :: %Ltix.LaunchClaims.LaunchPresentation{
  document_target: binary() | binary(),
  height: number(),
  locale: binary(),
  return_url: binary(),
  width: number()
}

Functions

from_json(json)

@spec from_json(map()) :: {:ok, t()} | {:error, Exception.t()}

Parse a launch presentation claim from a JSON map.

Examples

iex> Ltix.LaunchClaims.LaunchPresentation.from_json(%{})
{:ok, %Ltix.LaunchClaims.LaunchPresentation{document_target: nil, height: nil, width: nil, return_url: nil, locale: nil}}