Ltix.LaunchClaims.ToolPlatform (Ltix v0.1.0)

Copy Markdown View Source

Information about the platform instance that initiated the launch.

guid is required and stable for a given platform instance.

Examples

iex> Ltix.LaunchClaims.ToolPlatform.from_json(%{"guid" => "plat-1", "name" => "LMS"})
{:ok, %Ltix.LaunchClaims.ToolPlatform{guid: "plat-1", name: "LMS", contact_email: nil, description: nil, url: nil, product_family_code: nil, version: nil}}

Summary

Functions

Parse a tool platform claim from a JSON map.

Types

t()

@type t() :: %Ltix.LaunchClaims.ToolPlatform{
  contact_email: binary(),
  description: binary(),
  guid: binary(),
  name: binary(),
  product_family_code: binary(),
  url: binary(),
  version: binary()
}

Functions

from_json(json)

@spec from_json(map()) :: {:ok, t()} | {:error, Exception.t()}

Parse a tool platform claim from a JSON map.

Examples

iex> Ltix.LaunchClaims.ToolPlatform.from_json(%{"guid" => "plat-1"})
{:ok, %Ltix.LaunchClaims.ToolPlatform{guid: "plat-1", name: nil, contact_email: nil, description: nil, url: nil, product_family_code: nil, version: nil}}